@@ -41,7 +41,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, properties => [
     ),
 ];
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.2';
 
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
 my $SANE_NAME_SCAN_TL_Y   = SANE_NAME_SCAN_TL_Y;
@@ -246,13 +246,13 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
                 $hbox->pack_start( $label, FALSE, FALSE, 0 );
             }
 
-            # CheckButton
+            # Switch
             if ( $opt->{type} == SANE_TYPE_BOOL )
             {    ## no critic (ProhibitCascadingIfElse)
-                $widget = Gtk3::CheckButton->new;
+                $widget = Gtk3::Switch->new;
                 if ($val) { $widget->set_active(TRUE) }
                 $widget->{signal} = $widget->signal_connect(
-                    toggled => sub {
+                    'notify::active' => sub {
                         $self->{num_reloads} = 0;    # num-reloads is read-only
                         my $value = $widget->get_active;
                         $self->set_option( $opt, $value );
