@@ -10,12 +10,9 @@ use Gtk3;
 use List::Util qw(min);
 use Carp;
 use Readonly;
-Readonly my $HALF         => 0.5;
-Readonly my @PALE_BLUE    => ( 0.2, 0.6, 0.8 );
-Readonly my $ALPHA_FILL   => 0.2;
-Readonly my $ALPHA_BORDER => 0.35;
+Readonly my $HALF => 0.5;
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.2';
 
 # Note: in a BEGIN block to ensure that the registration is complete
 #       by the time the use Subclass goes to look for it.
@@ -85,19 +82,33 @@ sub INIT_INSTANCE {
     $self->signal_connect( 'motion-notify-event'  => \&_motion );
     $self->signal_connect( 'scroll-event'         => \&_scroll );
     $self->set_app_paintable(TRUE);
-    $self->add_events(
-        Glib::Object::Introspection->convert_sv_to_flags(
-            'Gtk3::Gdk::EventMask', 'exposure-mask' ) |
-          Glib::Object::Introspection->convert_sv_to_flags(
-            'Gtk3::Gdk::EventMask', 'button-press-mask' ) |
-          Glib::Object::Introspection->convert_sv_to_flags(
-            'Gtk3::Gdk::EventMask', 'button-release-mask' ) |
-          Glib::Object::Introspection->convert_sv_to_flags(
-            'Gtk3::Gdk::EventMask', 'pointer-motion-mask' ) |
-          Glib::Object::Introspection->convert_sv_to_flags(
-            'Gtk3::Gdk::EventMask', 'scroll-mask'
-          )
-    );
+    if (
+        $Glib::Object::Introspection::VERSION <
+        0.043    ## no critic (ProhibitMagicNumbers)
+      )
+    {
+        $self->add_events(
+            ${ Gtk3::Gdk::EventMask->new(qw/exposure-mask/) } |
+              ${ Gtk3::Gdk::EventMask->new(qw/button-press-mask/) } |
+              ${ Gtk3::Gdk::EventMask->new(qw/button-release-mask/) } |
+              ${ Gtk3::Gdk::EventMask->new(qw/pointer-motion-mask/) } |
+              ${ Gtk3::Gdk::EventMask->new(qw/scroll-mask/) } );
+    }
+    else {
+        $self->add_events(
+            Glib::Object::Introspection->convert_sv_to_flags(
+                'Gtk3::Gdk::EventMask', 'exposure-mask' ) |
+              Glib::Object::Introspection->convert_sv_to_flags(
+                'Gtk3::Gdk::EventMask', 'button-press-mask' ) |
+              Glib::Object::Introspection->convert_sv_to_flags(
+                'Gtk3::Gdk::EventMask', 'button-release-mask' ) |
+              Glib::Object::Introspection->convert_sv_to_flags(
+                'Gtk3::Gdk::EventMask', 'pointer-motion-mask' ) |
+              Glib::Object::Introspection->convert_sv_to_flags(
+                'Gtk3::Gdk::EventMask', 'scroll-mask'
+              )
+        );
+    }
     $self->set_tool('dragger');
     return $self;
 }
@@ -113,6 +124,9 @@ sub SET_PROPERTY {
         given ($name) {
             when ('pixbuf') {
                 $self->{$name} = $newval;
+                if ( not defined $newval ) {
+                    $invalidate = TRUE;
+                }
             }
             when ('zoom') {
                 $self->{$name} = $newval;
@@ -193,19 +207,6 @@ sub get_pixbuf_size {
     return;
 }
 
-sub get_zoomed_size {
-    my ($self) = @_;
-    my $size = $self->get_pixbuf_size;
-    if ( defined $size ) {
-        my $zoom = $self->get_zoom;
-        return {
-            width  => int( $size->{width} * $zoom + $HALF ),
-            height => int( $size->{height} * $zoom + $HALF )
-        };
-    }
-    return;
-}
-
 sub _button_pressed {
     my ( $self, $event ) = @_;
 
@@ -272,55 +273,42 @@ sub _draw {
     my ( $self, $context ) = @_;
     my $allocation = $self->get_allocation;
     my $style      = $self->get_style_context;
-    $style->add_class(Gtk3::STYLE_CLASS_BUTTON);
-    my $pixbuf = $self->get_pixbuf;
-    my ( $x, $y, $w, $h );
+    my $pixbuf     = $self->get_pixbuf;
+    my $viewport   = $self->get_viewport;
     if ( defined $pixbuf ) {
         my $zoom = $self->get_zoom;
         $context->scale( $zoom, $zoom );
         my $offset = $self->get_offset;
         $context->translate( $offset->{x}, $offset->{y} );
-        ( $x, $y, $w, $h ) = (
-            $self->_to_image_coords( 0, 0 ),
-            $self->_to_image_coords(
-                $allocation->{width}, $allocation->{height}
-            )
-        );
     }
-    else {
-        ( $x, $y, $w, $h ) =
-          ( 0, 0, $allocation->{width}, $allocation->{height} );
-    }
-    Gtk3::render_background( $style, $context, $x, $y, $w, $h );
-    Gtk3::render_frame( $style, $context, $x, $y, $w, $h );
+    $style->save;
+    $style->add_class(Gtk3::STYLE_CLASS_BACKGROUND);
+    Gtk3::render_background( $style, $context, $viewport->{x}, $viewport->{y},
+        $viewport->{width}, $viewport->{height} );
+    $style->restore;
     if ( defined $pixbuf ) {
         Gtk3::Gdk::cairo_set_source_pixbuf( $context, $pixbuf, 0, 0 );
     }
+    else {
+        my $bgcol = $style->get( 'normal', 'background-color' );
+        Gtk3::Gdk::cairo_set_source_rgba( $context, $bgcol );
+    }
     $context->paint;
 
     if ( defined $pixbuf and $self->get_tool eq 'selector' ) {
         my $selection = $self->get_selection;
         if ( defined $selection ) {
-            ( $x, $y, $w, $h, ) = (
+            my ( $x, $y, $w, $h, ) = (
                 $selection->{x},     $selection->{y},
                 $selection->{width}, $selection->{height},
             );
             if ( $w <= 0 or $h <= 0 ) { return TRUE }
 
-            $context->set_line_width(1);
-            $context->set_source_rgb( 0, 0, 0 );
-
-            # to get a non-antialiased rubber band rectangle,
-            # stroke needs half-integer coordinates,
-            # and fill/clip integer coordinates to be sharp.
-            $context->rectangle( $x + 1, $y + 1, $w - 2, $h - 2 );
-            $context->set_source_rgba( @PALE_BLUE, $ALPHA_FILL );
-            $context->fill();
-
-            $context->rectangle( $x + $HALF, $y + $HALF, $w - 1, $h - 1 );
-            $context->set_source_rgba( @PALE_BLUE, $ALPHA_BORDER );
-            $context->set_line_width(1);
-            $context->stroke();
+            $style->save;
+            $style->add_class(Gtk3::STYLE_CLASS_RUBBERBAND);
+            Gtk3::render_background( $style, $context, $x, $y, $w, $h );
+            Gtk3::render_frame( $style, $context, $x, $y, $w, $h );
+            $style->restore;
         }
     }
     return TRUE;
@@ -456,17 +444,21 @@ sub get_offset {
 sub get_viewport {
     my ($self)     = @_;
     my $allocation = $self->get_allocation;
-    my $zoomed     = $self->get_zoomed_size;
-    my $offset     = $self->get_offset;
-    if ( defined $zoomed ) {
-        return {
-            x      => $offset->{x},
-            y      => $offset->{y},
-            width  => min( $allocation->{width}, $zoomed->{width} ),
-            height => min( $allocation->{height}, $zoomed->{height} )
-        };
+    my $pixbuf     = $self->get_pixbuf;
+    my ( $x, $y, $w, $h );
+    if ( defined $pixbuf ) {
+        ( $x, $y, $w, $h ) = (
+            $self->_to_image_coords( 0, 0 ),
+            $self->_to_image_distance(
+                $allocation->{width}, $allocation->{height}
+            )
+        );
     }
-    return;
+    else {
+        ( $x, $y, $w, $h ) =
+          ( 0, 0, $allocation->{width}, $allocation->{height} );
+    }
+    return { x => $x, y => $y, width => $w, height => $h };
 }
 
 sub set_tool {
